@@ -16,6 +16,8 @@ local cursor = "0"
 repeat
     local result = redis.call("SCAN", cursor, "MATCH", pattern, "COUNT", 1000)
     local keys = result[2]
-    redis.call('DEL', unpack(keys))
+    if #keys ~= 0 then
+        redis.call('DEL', unpack(keys))
+    end
     cursor = result[1]
 until cursor == "0"
